/* Copyright (C) 1989 Aladdin Enterprises.  All rights reserved.
   Distributed by Free Software Foundation, Inc.

This file is part of Ghostscript.

Ghostscript is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY.  No author or distributor accepts responsibility
to anyone for the consequences of using it or for whether it serves any
particular purpose or works at all, unless he says so in writing.  Refer
to the Ghostscript General Public License for full details.

Everyone is granted permission to copy, modify and redistribute
Ghostscript, but only under the conditions described in the Ghostscript
General Public License.  A copy of this license is supposed to have been
given to you along with Ghostscript so you can know your rights and
responsibilities.  It should be in a file named COPYING.  Among other
things, the copyright notice and this notice must be preserved on all
copies.  */

/* gzstate.h */
/* Private graphics state definition for GhostScript library */
/* Requires gxmatrix.h and gxfixed.h */
#include "gsstate.h"

/* Graphics state structure.  See pp. 59-60 of the PostScript manual. */
struct gs_state_s {
	gs_state *saved;		/* previous state from gsave */
	gs_memory_procs memory_procs;
/* Transformation: */
	gs_matrix_fixed ctm;
#define ctm_only(pgs) *(gs_matrix *)&(pgs)->ctm
	gs_matrix ctm_inverse;
	int inverse_valid;		/* true if ctm_inverse = ctm^-1 */
/* Paths: */
	char *path_alloc_base;
	char *path_alloc_ptr;
	struct gx_path_s *path;
	struct gx_path_s *clip_path;
	int clip_rule;
/* Lines: */
	struct line_params_s *line_params;
/* Halftone screen: */
	struct halftone_s *halftone;
	float (*ht_proc)(P2(floatp, floatp));
/* Colors: */
	struct gs_color_s *color;
	float (*transfer)(P1(floatp));
/* Font: */
	struct gs_font_s *font;
	gs_matrix char_tm;		/* font matrix * ctm */
	int char_tm_valid;		/* true if char_tm is valid */
	int in_show;			/* true if inside a show */
/* Other stuff: */
	float flatness;
	struct device_s *device;
};
